"""
Simple Check of prime numbers, with the empiric indian math method.
"""


import math

def _test(number):
	if type(number) == int:
		if number >= 1:
			return True
	raise ValueError("The number is not integer or integer positive.")


"""
This function requires a integer number and 
return True if is prime or False if not
"""
def isPrime(number):
	if(_test(number)):
		global firstDivisor
		limit = range(2,int(math.sqrt(number))+1)
		for eachDivisor in limit:
			if number % eachDivisor == 0:
				firstDivisor = eachDivisor
				return False
		return True

"""
This function requires a integer number and return
a list of prime components of this number
"""
def primeComponents(number):
	if(_test(number)):
		pComponents = set([1])
		while(True):
			if(isPrime(number) == False):
				pComponents.add(firstDivisor)
				number = number // firstDivisor
			else:
				pComponents.add(number)
				return sorted(list(pComponents))






from distutils.core import setup

setup(
	name		= 'mosm_primes',
	version		= '1.0.3',
	py_modules	= ['primes'],
	author		= 'Marcelo Odir',
	author_email	= 'marceloodir@gmail.com',
	url		= '',
	description	= 'List of components prime of a integer number',
)
